@@ -3,8 +3,7 @@ from firestone import exceptions
 from django.contrib.auth import authenticate
 from django.conf import settings
 from django.utils import timezone
-from datetime import timedelta
-import jwt
+from itsdangerous import TimedJSONWebSignatureSerializer
 
 
 class ObtainJWTHandler(BaseHandler):
@@ -30,22 +29,11 @@ class ObtainJWTHandler(BaseHandler):
         self.request.data = user
 
     def post(self):
-        headers = {
-            'typ': 'JWT', 
-            'alg': 'HS512', 
-        }
-        payload = {
-            'iss': self.request.data.id,                  # issuer: The user making the request       
-            'iat': timezone.now(),                        # issued at
-            'exp': timezone.now() +  timedelta(days=1),   # expires at
-        }            
-
-        return {
-            'token': jwt.encode(
-                        headers=headers,
-                        payload=payload, 
-                        key=settings.SECRET_KEY,
-                        algorithm=headers['alg'],
-                     )
-        }
+        s = TimedJSONWebSignatureSerializer(
+            settings.SECRET_KEY, 
+            expires_in=3600*24
+        )
+        token = s.dumps({'iss': self.request.data.id} # ``iss`` symbolizes the issuer(user)
+        
+        return {'token': token}
 
