@@ -1,6 +1,7 @@
 from authentication import Authentication
 from authentication import NoAuthentication
 from authentication import SessionAuthentication
+from serializers import SerializerMixin
 from preserialize import serialize as preserializer
 import serializers 
 import deserializers
@@ -34,6 +35,10 @@ class HandlerMetaClass(type):
                 bases += (authentication,)
             else:
                 bases += (authentication,)
+
+        # Extend handler class with ``SerializerMixin`` class, so that it
+        # inherits its methods
+        bases += (SerializerMixin,)
         
         cls = type.__new__(meta, name, bases, attrs)
 
@@ -79,17 +84,14 @@ class HandlerControlFlow(object):
                 data, pagination,
             )
 
+            # If you want to alter the response object, override handler's
+            # ``get_response`` method
+            res = self.get_response(dic)
+
         except Exception, e:
-            # handle exception
-            response, headers = self.handle_exception(e)
-
-        else:
-            serialized_data, headers = serializers.serialize_response_data(
-                dic, self.request, self.args, self.kwargs
-            ) 
-            response = http.HttpResponse(serialized_data)            
-
-        return self.patch_response(response, headers)
+            res = self.handle_exception(e)
+        
+        return res
 
     def preprocess(self):
         """
@@ -157,13 +159,6 @@ class HandlerControlFlow(object):
         self.finalize_pending(data)
         # Package the python_data to a dictionary
         return self.package(python_data, pagination)
-        # Return serialized response plus any http headers, like
-        # ``content-type`` that need to be passed in the HttpResponse instance.
-        serialized, headers = serializers.serialize_response_data(
-            pack, self.request, self.args, self.kwargs
-        )
-        
-        return serialized, headers
 
     def handle_exception(self, e):
         """
@@ -178,10 +173,10 @@ class HandlerControlFlow(object):
             as headers on the HttpResponse object.
         """
         if isinstance(e, exceptions.APIException):
-            return e.get_http_response_and_headers()
+            return e.get_response(self.request)
         else:
             exc = exceptions.OtherException(self.request)
-            return exc.get_http_response_and_headers()
+            return exc.get_response(self.request)
 
 
 
@@ -225,6 +220,11 @@ class BaseHandler(HandlerControlFlow):
     # Defines whether metadata should be returned when pagination is used.
     # Generating metadata can, at times, perform costly queries.
     pagination_metadata = True
+
+    # Filename of Excel attachment in case a request needs the response data
+    # serialized to an excel file. Can be a string or a callable that returns a
+    # string
+    excel_filename = 'file.xls'
     
     def authentication_hook(self):
         """
